pub fn generate_backup_codes() -> Vec<EmailBackupCode>Expand description
Main entry function to generate backup codes, salts and hashing.
Generates a total of 10 backup codes with the appropriate salts and hashes for secure storage in the database. Each backup code generated is 24 characters long.
Returns
A Vec<EmailBackupCode> containing the generated backup codes, salts, and hashes
Example
let backup_codes = generate_backup_codes();